==> robodoc_4.0.18.orig.tar.gz: robodoc-4.0.18/Source/latex_generator.h <==
#ifndef ROBODOC_LATEX_GENERATOR_H
#define ROBODOC_LATEX_GENERATOR_H

#include "headers.h"

void                RB_LaTeX_Generate_Index_Entry( FILE * dest_doc,
                                                   struct RB_header
                                                   *cur_header );
void                RB_LaTeX_Generate_Item_Begin( FILE * dest_doc );
void                RB_LaTeX_Generate_Item_End( FILE * dest_doc );
void                RB_LaTeX_Generate_BeginSection( FILE * dest_doc,
                                                    int depth, char *name );
void                RB_LaTeX_Generate_EndSection( FILE * dest_doc, int depth,
                                                  char *name );
/* size_t RB_LaTeX_Get_Len_Extension(); */
/* void RB_LaTeX_Add_Extension(char* name); */
char               *RB_LaTeX_Get_Default_Extension( void );
void                RB_LaTeX_Generate_Item_Name( FILE * dest_doc,
                                                 char *name );
void                RB_LaTeX_Generate_Doc_Start( FILE * dest_doc,
                                                 char *src_name, char *name,
                                                 char toc );
void                RB_LaTeX_Generate_Doc_End( FILE * dest_doc, char *name );
void                RB_LaTeX_Generate_Header_Start( FILE * dest_doc,
                                                    struct RB_header
                                                    *cur_header );
void                RB_LaTeX_Generate_Header_End( FILE * dest_doc,
                                                  struct RB_header
                                                  *cur_header );
void                RB_LaTeX_Generate_Index( FILE * dest, char *source );
void                RB_Generate_LaTeX_Includes( FILE * dest );
void                RB_LaTeX_Generate_Index_Table( FILE * dest, int type,
                                                   char *title );
void                RB_LaTeX_Generate_Item_Doc( FILE * dest_doc,
                                                char *dest_name,
                                                char *begin_of_item,
                                                char *end_of_item,
                                                char *function_name,
                                                int item_type );
void                RB_LaTeX_Generate_Empty_Item( FILE * dest );
void                RB_LaTeX_Generate_Char( FILE * dest_doc, int c );
void                RB_LaTeX_Generate_False_Link( FILE * dest_doc,
                                                  char *name );

#endif /* ROBODOC_LATEX_GENERATOR_H */

==> robodoc-4.99.6.tar.gz: robodoc-4.99.6/Source/latex_generator.h <==
#ifndef ROBODOC_LATEX_GENERATOR_H
#define ROBODOC_LATEX_GENERATOR_H

#include "headers.h"

void                RB_LaTeX_Generate_Index_Entry( FILE * dest_doc,
                                                   struct RB_header
                                                   *cur_header );
void                RB_LaTeX_Generate_Item_Begin( FILE * dest_doc );
void                RB_LaTeX_Generate_Item_End( FILE * dest_doc );
void                RB_LaTeX_Generate_BeginSection( FILE * dest_doc,
                                                    int depth, char *name );
void                RB_LaTeX_Generate_EndSection( FILE * dest_doc, int depth,
                                                  char *name );
/* size_t RB_LaTeX_Get_Len_Extension(); */
/* void RB_LaTeX_Add_Extension(char* name); */
char               *RB_LaTeX_Get_Default_Extension( void );
void                RB_LaTeX_Generate_Item_Name( FILE * dest_doc,
                                                 char *name );
void                RB_LaTeX_Generate_Doc_Start( FILE * dest_doc,
                                                 char *src_name, char *name,
                                                 char toc );
void                RB_LaTeX_Generate_Doc_End( FILE * dest_doc, char *name );
void                RB_LaTeX_Generate_Header_Start( FILE * dest_doc,
                                                    struct RB_header
                                                    *cur_header );
void                RB_LaTeX_Generate_Header_End( FILE * dest_doc,
                                                  struct RB_header
                                                  *cur_header );
void                RB_LaTeX_Generate_Index( FILE * dest, char *source );
void                RB_Generate_LaTeX_Includes( FILE * dest );
void                RB_LaTeX_Generate_Index_Table( FILE * dest, int type,
                                                   char *title );
void                RB_LaTeX_Generate_Item_Doc( FILE * dest_doc,
                                                char *dest_name,
                                                char *begin_of_item,
                                                char *end_of_item,
                                                char *function_name,
                                                int item_type );
void                RB_LaTeX_Generate_Empty_Item( FILE * dest );
void                RB_LaTeX_Generate_Char( FILE * dest_doc, int c );
void                RB_LaTeX_Generate_False_Link( FILE * dest_doc,
                                                  char *name );

void RB_LaTeX_Generate_String( FILE* dest_doc, char *a_string );
void RB_LaTeX_Generate_EscapedChar( FILE * dest_doc, int c );

void LaTeX_Generate_Begin_Paragraph( FILE* dest_doc );
void LaTeX_Generate_End_Paragraph( FILE* dest_doc );
void LaTeX_Generate_Begin_Preformatted( FILE* dest_doc );
void LaTeX_Generate_End_Preformatted( FILE* dest_doc );
void LaTeX_Generate_Begin_List( FILE* dest_doc );
void LaTeX_Generate_End_List( FILE* dest_doc );
void LaTeX_Generate_Begin_List_Item( FILE* dest_doc );
void LaTeX_Generate_End_List_Item( FILE* dest_doc );

#endif /* ROBODOC_LATEX_GENERATOR_H */
